@@ -1,7 +1,7 @@
 /** ===========================================================
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2010-01-16
  * @brief  test for the model holding markers
@@ -21,20 +21,22 @@
  *
  * ============================================================ */
 
-#include "test_itemmarkertiler.moc"
+#include "test_itemmarkertiler.h"
+#include "kgeomap_common.h"
 
 // Qt includes
 
 #include <QStandardItemModel>
+#include <QDebug>
 
 using namespace KGeoMap;
 
 const int CoordinatesRole = Qt::UserRole + 0;
 
 MarkerModelHelper::MarkerModelHelper(QAbstractItemModel* const itemModel, QItemSelectionModel* const itemSelectionModel)
- : ModelHelper(itemModel),
-   m_itemModel(itemModel),
-   m_itemSelectionModel(itemSelectionModel)
+    : ModelHelper(itemModel),
+      m_itemModel(itemModel),
+      m_itemSelectionModel(itemSelectionModel)
 {
     connect(itemModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
             this, SLOT(slotDataChanged(QModelIndex,QModelIndex)));
@@ -96,7 +98,7 @@ int CountMarkersInIterator(ItemMarkerTiler::NonEmptyIterator* const it)
         const TileIndex currentIndex = it->currentIndex();
         markerCount                 += it->model()->getTileMarkerCount(currentIndex);
         it->nextIndex();
-//         kDebug()<<currentIndex;
+//         qDebug()<<currentIndex;
     }
 
     return markerCount;
@@ -245,7 +247,7 @@ void TestItemMarkerTiler::testMoveMarkers2()
     const QModelIndex markerIndex1 = itemModel->indexFromItem(item1);
     QStandardItem* const item2     = MakeItemAt(coord_1_2);
     itemModel->appendRow(item2);
-    const QModelIndex markerIndex2 = itemModel->indexFromItem(item2);
+//    const QModelIndex markerIndex2 = itemModel->indexFromItem(item2);
 
     for (int l = 1; l <= fillLevel; ++l)
     {
@@ -258,8 +260,8 @@ void TestItemMarkerTiler::testMoveMarkers2()
 
     QStandardItem* const item3     = MakeItemAt(coord_50_60);
     itemModel->appendRow(item3);
-    const QModelIndex markerIndex3 = itemModel->indexFromItem(item3);
- 
+//    const QModelIndex markerIndex3 = itemModel->indexFromItem(item3);
+
     for (int l = 1; l <= fillLevel; ++l)
     {
         const TileIndex tileIndex           = TileIndex::fromCoordinates(coord_50_60, l);
@@ -512,7 +514,7 @@ void TestItemMarkerTiler::testSelectionState1()
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
         QVERIFY(myTile != 0);
         QVERIFY(mm.getTileMarkerCount(tileIndex) == 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedNone);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedNone);
     }
 
     selectionModel->select(item1Index, QItemSelectionModel::Select);
@@ -524,7 +526,7 @@ void TestItemMarkerTiler::testSelectionState1()
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
         QVERIFY(mm.getTileSelectedCount(tileIndex)==1);
     }
 
@@ -540,7 +542,7 @@ void TestItemMarkerTiler::testSelectionState1()
         ItemMarkerTiler::Tile* const myTile = mm.getTile(tileIndex, true);
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedSome);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedSome);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
     }
 
@@ -553,7 +555,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 2);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     // now remove the selected item:
@@ -568,7 +570,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     // add a selected item and then move it:
@@ -585,7 +587,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     for (int l = 0; l <= maxLevel; ++l)
@@ -595,7 +597,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     itemModel->setData(item3Index, QVariant::fromValue(coord_50_60), CoordinatesRole);
@@ -607,7 +609,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 2);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 2);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     itemModel->setData(item3Index, QVariant::fromValue(coord_m50_m60), CoordinatesRole);
@@ -619,7 +621,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     for (int l = 0; l <= maxLevel; ++l)
@@ -629,7 +631,7 @@ void TestItemMarkerTiler::testSelectionState1()
         QVERIFY(myTile != 0);
         QCOMPARE(mm.getTileMarkerCount(tileIndex), 1);
         QCOMPARE(mm.getTileSelectedCount(tileIndex), 1);
-        QVERIFY(mm.getTileGroupState(tileIndex)==KGeoMapSelectedAll);
+        QVERIFY(mm.getTileGroupState(tileIndex)==SelectedAll);
     }
 
     // TODO: set a model with selected items, make sure the selections are read out
@@ -677,4 +679,4 @@ void TestItemMarkerTiler::benchmarkIteratorWholeWorld()
 #endif
 }
 
-QTEST_MAIN(TestItemMarkerTiler)
+QTEST_GUILESS_MAIN(TestItemMarkerTiler)
